package de.fhdw.wtf.common.ast;

import de.fhdw.wtf.common.ast.visitor.OperationModifierVisitor;
import de.fhdw.wtf.common.ast.visitor.OperationModifierVisitorReturn;
import de.fhdw.wtf.common.token.Token;

/**
 * This class represents a modifier of an {@link Operation}. A modifier comes to effect at the code generation.
 * 
 */
public abstract class OperationModifier extends SyntaxObject {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = -4853317676624075910L;
	
	/**
	 * Protected-Constructor of {@link OperationModifier}.
	 * 
	 * @param firstToken
	 *            firstToken
	 * @param lastToken
	 *            lastToken
	 */
	protected OperationModifier(final Token firstToken, final Token lastToken) {
		super(firstToken, lastToken);
	}
	
	/**
	 * Accepts the sub types of {@link OperationModifier} and implements the required functions.
	 * 
	 * @param visitor
	 *            is visitor that describes what has to be done for the particular {@link OperationModifier}.
	 * @return Boolean
	 */
	public abstract boolean accept(OperationModifierVisitor visitor);
	
	/**
	 * Accepts a visitor with dynamic return type.
	 * 
	 * @param visitor
	 *            The Visitor to be accepted.
	 * @param <X>
	 *            ReturnType
	 * @return X.
	 */
	public abstract <X> X accept(OperationModifierVisitorReturn<X> visitor);
	
}
