package de.fhdw.wtf.common.exception.referencer;

import de.fhdw.wtf.common.ast.Constructor;
import de.fhdw.wtf.common.constants.referencer.ExceptionConstans;
import de.fhdw.wtf.common.token.Token;

/**
 * A Method of the {@link de.fhdw.wtf.walker.tasks.ConstructorReferencer} throws it.
 * 
 */
public final class CyclicConstructorCallException extends ReferencerException {
	
	/**
	 * Constructor of {@link CyclicConstructorCallException}.
	 * 
	 * @param callingConstructor
	 *            the constructor which calls itself.
	 * 
	 * @param token
	 *            token
	 */
	private CyclicConstructorCallException(final Constructor callingConstructor, final Token token) {
		super(token, ExceptionConstans.CYCLIC_CONSTRUCTOR_CALL_MESSAGE
				+ callingConstructor.toStringWithoutSuperconstructors());
	}
	
	/**
	 * Constructor of {@link CyclicConstructorCallException}.
	 * 
	 * @param callingConstructor
	 *            the constructor which calls itself.
	 * 
	 * @param token
	 *            token
	 * @return an instance of {@link CyclicConstructorCallException}.
	 */
	public static CyclicConstructorCallException create(final Constructor callingConstructor, final Token token) {
		return new CyclicConstructorCallException(callingConstructor, token);
	}
	
}
