package de.fhdw.wtf.common.exception.walker;

import de.fhdw.wtf.common.ast.Constructor;
import de.fhdw.wtf.common.ast.ConstructorReference;
import de.fhdw.wtf.common.constants.walker.ExceptionConstants;

/**
 * Represents existence of an invalid {@link ConstructorReference} instance.
 */
public final class InvalidConstructorReferenceListException extends EditorMarkableConstructorException {
	
	/**
	 * Instantiates a {@link InvalidConstructorReferenceListException}.
	 * 
	 * @param callingConstructor
	 *            the calling constructor with the invalid constructor reference list.
	 * @param message
	 *            a matching exception message preferable from the {@link ExceptionConstants}.
	 */
	private InvalidConstructorReferenceListException(final Constructor callingConstructor, final String message) {
		super(callingConstructor, message + callingConstructor.toString());
	}
	
	/**
	 * Instantiates a {@link InvalidConstructorReferenceListException}.
	 * 
	 * @param callingConstructor
	 *            the calling constructor with the invalid constructor reference list.
	 * @param message
	 *            a matching exception message preferable from the {@link ExceptionConstants}.
	 * 
	 * @return an instance of {@link InvalidConstructorReferenceListException}.
	 * 
	 */
	public static InvalidConstructorReferenceListException create(final Constructor callingConstructor,
			final String message) {
		return new InvalidConstructorReferenceListException(callingConstructor, message);
	}
}
