package de.fhdw.wtf.common.token;

/**
 * This token contains a whole comment in the original formatting.
 * 
 */
public final class CommentTextToken extends MultiCharToken {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = 6189611405583012863L;
	
	/**
	 * Private Constructor for CommentTextToken. Use create(...)-Factory instead!
	 * 
	 * @param commentText
	 *            initial comment text
	 * @param position
	 *            start position of this comment in the original input
	 */
	private CommentTextToken(final String commentText, final Position position) {
		super(commentText, position);
	}
	
	/**
	 * Factory for a {@link CommentTextToken}.
	 * 
	 * @param commentText
	 *            initial comment text
	 * @param position
	 *            start position of this comment in the original input
	 * @return a new instance of this token
	 */
	public static CommentTextToken create(final String commentText, final Position position) {
		return new CommentTextToken(commentText, position);
	}
	
	@Override
	public boolean isCommentToken() {
		return true;
	}
	
	/**
	 * Getter for the whole comment.
	 * 
	 * @return comment string
	 */
	public String getCommentText() {
		return this.getTokenString();
	}
	
	@Override
	protected boolean equalsTemplate(final Token t) {
		if (t.isCommentToken()) {
			final CommentTextToken ct = (CommentTextToken) t;
			return this.getCommentText().equals(ct.getCommentText());
		}
		return false;
	}
	
	@Override
	protected int hashCodeTemplate() {
		return this.getCommentText().hashCode();
	}
	
}
