package de.fhdw.wtf.common.token.keywords;

import de.fhdw.wtf.common.token.Position;
import de.fhdw.wtf.common.token.Token;

/**
 * Represents the exception as a token in WTF.
 */
public final class ExceptionToken extends KeywordToken {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = -9105401325558585035L;
	
	/**
	 * Defines constant for hashCodeTemplate().
	 */
	private static final int HASHCODE_TEMPLATE_CONSTANT = 874834;
	
	/**
	 * Defines constant "exception" for {@link ExceptionToken}.
	 */
	private static final String TEXTUAL_REPRESENTATION = "exception";
	
	/**
	 * Private constructor for {@link ExceptionToken}. Use create(...)-Factory instead!
	 * 
	 * @param position
	 *            represents the start position of an {@link ExceptionToken} in the original input.
	 */
	private ExceptionToken(final Position position) {
		super(position);
	}
	
	/**
	 * Factory method for {@link ExceptionToken}.
	 * 
	 * @param position
	 *            represents the start position of this {@link KeywordToken} in the original input.
	 * @return a new instance of this {@link KeywordToken}.
	 */
	public static ExceptionToken create(final Position position) {
		return new ExceptionToken(position);
	}
	
	@Override
	public int getLength() {
		return ExceptionToken.TEXTUAL_REPRESENTATION.length();
	}
	
	@Override
	public boolean isExceptionToken() {
		return true;
	}
	
	@Override
	protected boolean equalsTemplate(final Token t) {
		return t.isExceptionToken();
	}
	
	@Override
	public String stringRepresentation() {
		return TEXTUAL_REPRESENTATION;
	}
	
	@Override
	protected int hashCodeTemplate() {
		return HASHCODE_TEMPLATE_CONSTANT;
	}
	
}
