package de.fhdw.wtf.common.token.symbols;

import de.fhdw.wtf.common.token.Position;
import de.fhdw.wtf.common.token.Token;

/**
 * Represents the comma ',' symbol as a token.
 */
public final class CommaToken extends SymbolToken {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = -2882344445175813355L;
	
	/**
	 * Defines constant for hashCodeTemplate().
	 */
	private static final int HASHCODE_TEMPLATE_CONSTANT = 127612;
	
	/**
	 * Private constructor for {@link CommaToken}. Use create(...)-Factory instead!
	 * 
	 * @param position
	 *            represents the start position of the symbol ',' in the original input.
	 */
	private CommaToken(final Position position) {
		super(position, SymbolConstants.COMMA);
	}
	
	/**
	 * Factory method for {@link CommaToken}.
	 * 
	 * @param position
	 *            represents the start position of this {@link SymbolToken} in the original input.
	 * @return a new instance of this {@link SymbolToken}.
	 */
	public static CommaToken create(final Position position) {
		return new CommaToken(position);
	}
	
	@Override
	protected boolean equalsTemplate(final Token t) {
		return t.isCommaToken();
	}
	
	@Override
	public String stringRepresentation() {
		return SymbolConstants.COMMA;
	}
	
	@Override
	public boolean isCommaToken() {
		return true;
	}
	
	@Override
	protected int hashCodeTemplate() {
		return HASHCODE_TEMPLATE_CONSTANT;
	}
	
}
