package de.fhdw.wtf.dsl.scanner.common;

import de.fhdw.wtf.common.stream.TokenStream;
import de.fhdw.wtf.common.token.Position;
import de.fhdw.wtf.dsl.scanner.modelScanner.state.ScannerStateVisitor;

/**
 * This state represents a possible state of the Scanner while scanning the input stream. Instances of this state have
 * to process incoming characters for the scanner.
 */
public interface ScannerState {
	
	/**
	 * Processes the given input char and returns the next state of the Scanner. If the state completely processed a
	 * char, a token in the outputstream is generated.
	 * 
	 * @param input
	 *            character to be processed in this state
	 * @param outputStream
	 *            for resulting Tokens
	 * @param position
	 *            position of input char in original stream
	 */
	void process(char input, TokenStream outputStream, Position position);
	
	/**
	 * Finishes this state. Creates all necessary tokens to present all information.
	 * 
	 * @param outputStream
	 *            for resulting Tokens
	 */
	void finish(TokenStream outputStream);
	
	/**
	 * Accept-Operation.
	 * 
	 * @param visitor
	 *            {@link ScannerStateVisitor}
	 * @return Boolean
	 */
	boolean accept(ScannerStateVisitor visitor);
	
}
