package de.fhdw.wtf.dsl.scanner.modelScanner.state;

import de.fhdw.wtf.common.stream.TokenStream;
import de.fhdw.wtf.common.token.InvalidToken;
import de.fhdw.wtf.common.token.Position;

/**
 * ScannerState for recognition of any {@link Character} <br>
 * that hasn't been recognised by any other ScannerState.
 */
public final class InvalidState extends MultiCharState {
	
	/**
	 * PRIVATE Constructor.
	 * 
	 * @param currentInput
	 *            startInput
	 * @param firstPosition
	 *            of the first char.
	 */
	private InvalidState(final String currentInput, final Position firstPosition) {
		super(currentInput, firstPosition);
	}
	
	/**
	 * Factory for {@link InvalidState}.
	 * 
	 * @param position
	 *            of the first char.
	 * @return {@link InvalidState}
	 */
	public static InvalidState create(final Position position) {
		return new InvalidState("", position);
	}
	
	@Override
	public void finish(final TokenStream outputStream) {
		if (!this.getCurrentInput().isEmpty()) {
			outputStream.add(InvalidToken.create(this.getCurrentInput(), this.getFirstPosition()));
		}
	}
	
	/**
	 * Checks if the given char is invalid for WTF-Code.
	 * 
	 * @param input
	 *            char
	 * @return true if invalid
	 */
	public static boolean isInValid(final char input) {
		return !SymbolState.isSymbol(input) && !KeywordIdentifierState.isAllowedCharacter(input)
				&& !Character.isWhitespace(input) && input != '#';
	}
	
	@Override
	public boolean accept(final ScannerStateVisitor visitor) {
		return visitor.handleInvalidState();
	}
}
