package de.fhdw.wtf.dsl.scanner.modelScanner.state;

import de.fhdw.wtf.common.stream.TokenStream;
import de.fhdw.wtf.common.token.Position;
import de.fhdw.wtf.common.token.WhitespaceToken;

/**
 * ScannerState for recognition of whitespace.
 */
public final class WhitespaceState extends MultiCharState {
	
	/**
	 * PRIVATE Constructor.
	 * 
	 * @param currentInput
	 *            startInput.
	 * @param firstPosition
	 *            of the first char.
	 */
	private WhitespaceState(final String currentInput, final Position firstPosition) {
		super(currentInput, firstPosition);
	}
	
	/**
	 * Factorymethod for {@link WhitespaceState}.
	 * 
	 * @param firstPosition
	 *            of the first char.
	 * @return the {@link WhitespaceState}.
	 */
	public static WhitespaceState create(final Position firstPosition) {
		return new WhitespaceState("", firstPosition);
	}
	
	@Override
	public void finish(final TokenStream outputStream) {
		if (!this.getCurrentInput().isEmpty()) {
			outputStream.add(WhitespaceToken.create(this.getCurrentInput(), this.getFirstPosition()));
		}
	}
	
	@Override
	public boolean accept(final ScannerStateVisitor visitor) {
		return visitor.handleWhitespaceState();
	}
	
}
