package de.fhdw.wtf.walker.tasks;

import java.util.Collection;

import de.fhdw.wtf.common.ast.Attribute;
import de.fhdw.wtf.common.ast.ConstructorOrOperation;
import de.fhdw.wtf.common.ast.Group;
import de.fhdw.wtf.common.ast.Model;
import de.fhdw.wtf.common.ast.type.ClassType;
import de.fhdw.wtf.common.ast.type.Type;
import de.fhdw.wtf.common.exception.walker.BaseTypeInheritanceException;
import de.fhdw.wtf.common.exception.walker.TaskException;
import de.fhdw.wtf.common.task.TaskExecutor;
import de.fhdw.wtf.walker.walker.HelperUtils;
import de.fhdw.wtf.walker.walker.SimpleWalkerTask;

/**
 * This Task check the Inheritance-Structur. If a Class extends a BaseType, this checker will thrown a
 * {@link de.fhdw.wtf.common.exception.walker.BaseTypeInheritanceException}.
 * 
 * This Checker must run after the {@link TypeReferencer}.
 */
public final class BaseTypeInheritanceCheck extends SimpleWalkerTask {
	/**
	 * Constructor of {@link BaseTypeInheritanceCheck}.
	 * 
	 * @param m
	 *            model
	 * @param taskmanager
	 *            taskmanager
	 */
	private BaseTypeInheritanceCheck(final Model m, final TaskExecutor taskmanager) {
		super(m, taskmanager);
	}
	
	/**
	 * Creates a {@link BaseTypeInheritanceCheck}-Object.
	 * 
	 * @param m
	 *            model
	 * @param taskmanager
	 *            taskmanager
	 * @return The {@link BaseTypeInheritanceCheck}-Object.
	 */
	public static BaseTypeInheritanceCheck create(final Model m, final TaskExecutor taskmanager) {
		return new BaseTypeInheritanceCheck(m, taskmanager);
	}
	
	@Override
	public void handleGroup(final Group g) throws TaskException {
		// Nothing to do here
	}
	
	@Override
	public void handleClass(final ClassType c) throws TaskException {
		final Collection<Type> superTypes = c.getSuperTypes();
		for (final Type currentSuperType : superTypes) {
			final Type targetType = HelperUtils.getReferencedType(currentSuperType);
			if (targetType.equals(this.getModel().getInteger()) || targetType.equals(this.getModel().getString())) {
				throw BaseTypeInheritanceException.create(
						c.getName(),
						currentSuperType.getFirstToken(),
						currentSuperType.getLastToken());
			}
		}
	}
	
	@Override
	public void handleAttribute(final Attribute a, final ClassType owner) throws TaskException {
		// Nothing to do here
	}
	
	@Override
	public void handleConstructorOrOperation(final ConstructorOrOperation coo, final ClassType owner)
			throws TaskException {
		// Nothing to do here
	}
	
	@Override
	public void finalizeTask() throws TaskException {
		// Nothing to do here
	}
	
	@Override
	public void beginTask() throws TaskException {
		// Nothing to do here
	}
}
